function SceneNavigationMenuMovies(options)
{
	this.options = options;
    this.selfState = new Object();
    this.refreshMovieSceneTimer = null;
}

SceneNavigationMenuMovies.prototype.initialize = function ()
{
	alert("SceneNavigationMenuMovies.initialize()");
}

SceneNavigationMenuMovies.prototype.buildList = function (obj)
{
    if (obj.type != "playlist")
    {
        $.sfScene.get("Main").showError("NavigationMenuMovies", "Przepraszamy, wystąpił błąd serwera [3x1].");
        return false;
    }
    
    var caller = this;
    
    this.selfState.caption = obj.caption;
    
    $("#movieDescLabel").html(obj.caption);
    
    if (obj.feeds.length == 0)
    {
        $.sfScene.get("Main").showError("NavigationMenuMovies", "Lista filmów jest pusta [3x2].");
    }
    
    $("#menuMoviesListbox").sfListbox2(
    {
        data: obj.feeds,
        itemsPerPage: 5,
        index: this.selfState.cursor,
        getElementContentCallback: function(obj)
        {
            if (typeof obj != "object")
            {
                alert("getElementContentCallback: Object expected");
                return "";
            }
            
            var content = "";
            content += "<img src='"+obj.img+"' />";
            content += "<div class='wrapper'>";
            content += "<div class='title'>"+obj.title+"</div>";
            content += "<div class='rating'>Ocena: "+obj.rating+"</div>";
            
            if (typeof obj.duration == "number")
            {
                content += "<div class='duration'>Czas trwania: "+obj.duration+" min.</div>";
            }
            else if (typeof obj.movies_count == "number")
            {
                content += "<div class='movies_count'>Liczba odcinków: "+obj.movies_count+" odc.</div>";
            }
            
            content += "</div>";
            
            return content;
        },
        clickElementCallback: function(obj)
        {
            if (typeof obj != "object")
            {
                alert("clickElementCallback: Object expected");
                return false;
            }
            
            var newScene = new Object();
            newScene.url = obj.url;
            newScene.caption = obj.caption;
            newScene.type = obj.type;
            newScene.cursor = 0;
            
            return $.sfScene.get("Main").sendRequestForData(newScene, caller.selfState);
        }
    });
    
    $.sfScene.get("Main").sendRequestForData($("#menuMoviesListbox").sfListbox2("getCurrentElement"));
    
    return true;
}

SceneNavigationMenuMovies.prototype.sendRequestForData = function (obj)
{
    $("#menuMoviesListbox").html('<img src="images/loading.gif" class="loadingImage" />');
    
    this.selfState = obj;
    var caller = this;
    
    menuXHR =  $.sfScene.get("Main").getXHRObj("NavigationMenuMovies");
    menuXHR.sendXHRRequest(this.selfState.url, function (result, respObj)
    {    
        if (result)
        {
            caller.buildList($.parseJSON(respObj.responseText));
            return true;
        }
        else
        {
            $.sfScene.get("Main").showError("NavigationMenuMovies", "Przepraszamy, wystąpił błąd z połączeniem [3x0].<br />Prosimy spróbować ponownie za chwilę.");
            return false;
        }
    });
}

SceneNavigationMenuMovies.prototype.helpBar = function ()
{
    var helpbar = new Object();
    
    var prevScene = $.sfScene.get("Main").prevScene;
    
    if (prevScene.length == 0)
    {
        helpbar["return"] = "Wyjdź";
    }
    else
    {
        if (typeof prevScene[prevScene.length - 1].caption == "")
        {
            helpbar["return"] = "Wróć";
        }
        else
        {
            helpbar["return"] = "Wróć do " + prevScene[prevScene.length - 1].caption;
        }
    }
    
    $.sfScene.get("Main").helpBar(helpbar);
}

SceneNavigationMenuMovies.prototype.focusListElement = function (position)
{
    clearTimeout(this.refreshMovieSceneTimer);
    $.sfScene.get("Movie").setFocusable(false);
    $.sfScene.get("Movie").resetButtons(false);
    $("#menuMoviesListbox").sfListbox2("setPosition", position);
    this.selfState.cursor = $("#menuMoviesListbox").sfListbox2("getIndex");
    $("#menuMoviesListbox").sfListbox2("focus");
    $.sfScene.get("Main").sendRequestForData($("#menuMoviesListbox").sfListbox2("getCurrentElement"));
}

SceneNavigationMenuMovies.prototype.handleShow = function ()
{
	alert("SceneNavigationMenuMovies.handleShow()");
    
    this.helpBar();
}

SceneNavigationMenuMovies.prototype.handleHide = function ()
{
	alert("SceneNavigationMenuMovies.handleHide()");
    
    $("#menuMoviesListbox").sfListbox2("clear");
    $.sfScene.get("Main").getXHRObj("NavigationMenuMovies").abortXHRObj();
}

SceneNavigationMenuMovies.prototype.handleFocus = function ()
{
	alert("SceneNavigationMenuMovies.handleFocus()");
    
    $("#menuMoviesListbox").sfListbox2("focus");
}

SceneNavigationMenuMovies.prototype.handleBlur = function ()
{
	alert("SceneNavigationMenuMovies.handleBlur()");
    
    $("#menuMoviesListbox").sfListbox2("blur");
}

SceneNavigationMenuMovies.prototype.handleKeyDown = function (keyCode)
{
	alert("SceneNavigationMenuMovies.handleKeyDown(" + keyCode + ")");
    
	switch (keyCode)
    {
		case $.sfKey.RIGHT:
            if ($.sfScene.get("Movie").getFocusable())
            {
                $.sfScene.focus("Movie");
            }
			break;
            
            
		case $.sfKey.UP:
            clearTimeout(this.refreshMovieSceneTimer);
            $.sfScene.get("Movie").setFocusable(false);
            $.sfScene.get("Movie").resetButtons(false);
            $("#menuMoviesListbox").sfListbox2("prev");
            this.selfState.cursor = $("#menuMoviesListbox").sfListbox2("getIndex");
            this.refreshMovieSceneTimer = setTimeout('$.sfScene.get("Main").sendRequestForData($("#menuMoviesListbox").sfListbox2("getCurrentElement"))', conf.refreshMovieSceneTimeout);
			break;
            
		case $.sfKey.DOWN:
            clearTimeout(this.refreshMovieSceneTimer);
            $.sfScene.get("Movie").setFocusable(false);
            $.sfScene.get("Movie").resetButtons(false);
            $("#menuMoviesListbox").sfListbox2("next");
            this.selfState.cursor = $("#menuMoviesListbox").sfListbox2("getIndex");
            this.refreshMovieSceneTimer = setTimeout('$.sfScene.get("Main").sendRequestForData($("#menuMoviesListbox").sfListbox2("getCurrentElement"))', conf.refreshMovieSceneTimeout);
            break;
            
            
		case $.sfKey.GREEN:
		case $.sfKey.BLUE:
		case $.sfKey.RED:
        case $.sfKey.YELLOW:
        case $.sfKey.ENTER:
            $.sfScene.get("Movie").handleKeyDown(keyCode);
			break;
            
            
        case $.sfKey.RETURN:
            $.sfKey.block();
            $.sfScene.get("Main").goBack();
            break;
	}
}
